``neutcurve`` documentation
======================================

`neutcurve` is a Python package written by the `Bloom lab <https://research.fhcrc.org/bloom/en.html>`_ for fitting and plotting neutralization curves.

See below for information and examples of how to use this package.

Please cite `Loes et al (2024) <https://doi.org/10.1101/2024.03.08.584176>`_ if you use `neutcurve` in your scientific study.

Contents
----------
.. toctree::
   :hidden:

   self

.. toctree::
   :maxdepth: 2

   installation
   hillcurve_example
   curvefits_example
   constrain_params_range
   combine_curvefits
   test_curves
   neutcurve
   package_index
   acknowledgments
